gravitational_constant = 6.67430e-11

def acceleration_due_to_gravity(double mass, double distance):
    return (gravitational_constant * mass) / distance ** 2

__all__ = ['gravitational_constant', 'acceleration_due_to_gravity']


import setuptools

setuptools.setup(
    name = 'python-gravity',
    version = '0.5.0',
    url = 'https://github.com/gaming32/pygravity',
    author = 'Gaming32',
    author_email = 'gaming32i64@gmail.com',
    license = 'License :: OSI Approved :: MIT License',
    description = 'Library for calculating stuff having to do with gravity',
    long_description = '',
    long_description_content_type = 'text/markdown',
    packages = [
        'pygravity',
        'pygravity.twod',
    ],
    ext_modules = [
        setuptools.Extension('pygravity.math', ['pygravity/math.c']),
        setuptools.Extension('pygravity.twod.gravity', ['pygravity/twod/gravity.c']),
        setuptools.Extension('pygravity.twod.physics', ['pygravity/twod/physics.c']),
        setuptools.Extension('pygravity.twod.vector', ['pygravity/twod/vector.c']),
    ],
    zip_safe = False,
)


from .vector import Vector2
from .gravity import GravityContainer, GravityCaster, GravityAcceptor
from .physics import PhysicsManager

__all__ = ['Vector2',
           'GravityContainer', 'GravityCaster', 'GravityAcceptor',
           'PhysicsManager']